#!/bin/sh
#
# Globus post install script
#
# 2002 - Anders Waananen <waananen@nbi.dk>

# Modification by Charles Loomis <charles.loomis@cern.ch>
# to check globus sysconfig file for globus location.
if test ! "x$1" = "x" ; then
  GLOBUS_LOCATION=$1
else
  if [ -r /etc/sysconfig/globus ]; then
    . /etc/sysconfig/globus
  fi
fi

if test "x$GLOBUS_LOCATION" = "x"; then
  echo "GLOBUS_LOCATION not set" 1>&2
  exit 1
fi

if test -d "$GLOBUS_LOCATION" ; then
  PATH=$GLOBUS_LOCATION/bin:$PATH
  export PATH
else
  echo "GLOBUS directory: $GLOBUS_LOCATION does not exists" 1>&2
  exit 1
fi

export GLOBUS_LOCATION

if test -f $GLOBUS_LOCATION/lib/perl/Grid/GPT/Setup.pm ; then

  GPT_LOCATION=$GLOBUS_LOCATION

else

  if test "x$GPT_LOCATION" = "x" ; then
    if test -f /etc/profile.d/gpt.sh ; then
      source /etc/profile.d/gpt.sh
    fi
  fi

  if ! test -f $GPT_LOCATION/lib/perl/Grid/GPT/Setup.pm ; then
    echo "Failure: GPT_LOCATION or GLOBUS_LOCATION needs to point to gpt installation" 1>&2
    exit 1
  fi
fi

export GPT_LOCATION

# Standard Globus setup packages
cd $GLOBUS_LOCATION/setup/globus

if test -f setup-globus-core ; then
  ./setup-globus-core
fi

./setup-globus-common      # globus-script-initializer globus-sh-tools-var.sh Globus::Core::Paths
./setup-globus-mds-common  # grid-info.conf
./setup-globus-mds-gris    # globus providers...
./setup-globus-gatekeeper  # globus-gatekeeper.conf var grid-services
./setup-globus-gram-job-manager # globus-job-manager.conf
./setup-globus-gram-reporter-fork
./setup-globus-gram-reporter-pbs
./setup-globus-gram-reporter-condor
./setup-globus-gram-reporter-lsf
./setup-globus-job-manager-fork
./setup-globus-job-manager-pbs
./setup-globus-job-manager-condor
./setup-globus-job-manager-lsf
# This needs arguments.
# ./setup-globus-job-manager-remote

# Setup the optional job managers that LCG may install
if test -x setup-globus-job-manager-lcgpbs ; then
  ./setup-globus-job-manager-lcgpbs
fi
if test -x setup-globus-job-manager-lcglsf ; then
  ./setup-globus-job-manager-lcglsf
fi
if test -x setup-globus-job-manager-lcgcondor ; then
  ./setup-globus-job-manager-lcgcondor
fi
if test -x setup-globus-gram-reporter-lcgpbs ; then
  ./setup-globus-gram-reporter-lcgpbs
fi
if test -x setup-globus-gram-reporter-lcglsf ; then
  ./setup-globus-gram-reporter-lcglsf
fi
if test -x setup-globus-gram-reporter-lcgcondor ; then
  ./setup-globus-gram-reporter-lcgcondor
fi

# Do not run the full security setup (setup-ssl-utils)
#
# What it does:
# setup-ssl-utils:
#
# - Runs setup-ssl-utils-sh-scripts
#        - Creates grid-security-config     from grid-security-config.in and
#                  grid-cert-request-config from grid-cert-request-config.in
# - And makes the created scripts executable
# - Runs setup-gsi
#
# Instead we just do:
./setup-ssl-utils-sh-scripts
chmod 755 grid-cert-request-config
